MappedColors class

Constructors

MappedColors()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

border ↔ _BorderColors
getter/setter pair
icon ↔ _IconColors
getter/setter pair
surface ↔ _SurfaceColors
getter/setter pair
text ↔ _TextColors
getter/setter pair